@@ -16,22 +16,32 @@ public:
 	explicit SetHist(QObject* parent = 0);
 	SetHist(const SetHist&);
 	Q_PROPERTY(QVariantList documents READ documents())
-	Q_PROPERTY(QVariantMap curDoc READ curDoc() WRITE setCurDoc())
+	Q_PROPERTY(QVariantMap curDoc READ curDoc() WRITE setCurDoc() NOTIFY curDocChanged())
 	
 	QVariantList documents();
 	QVariantMap curDoc();
+	void setWindowWidget(QWidget *wdgt);
 	
 	
 signals:
+	void curDocChanged();
 public slots:
 	void newDocument(QVariantMap doc);
-	void chooseFile();
+	bool chooseFile();
 	void setCurDoc(QVariantMap doc);
 	void clearDocuments();
+	void setCursorImage(QString img);
+	void setCursorShape(int shape);
+	void setValue (QString name, const QVariant &value);
+	QVariant value(QString name);
+	static void setUpdateMode(int mode);
+	static void log(QVariant str);
+	static QString platform();
 	
 private:
 	QSettings qs;
 	QVariantList documents_prv;
+	QWidget *windowWidget;
 };
 Q_DECLARE_METATYPE (SetHist)
 #endif // SETHIST_H
